@@ -38,13 +38,10 @@ void KateAppAdaptor::activate()
         return;
     }
 
-    win->show();
-    win->activateWindow();
+    // like QtSingleApplication
+    win->setWindowState(win->windowState() & ~Qt::WindowMinimized);
     win->raise();
-
-    KWindowSystem::forceActiveWindow(win->winId());
-    KWindowSystem::raiseWindow(win->winId());
-    KWindowSystem::demandAttention(win->winId());
+    win->activateWindow();
 }
 
 bool KateAppAdaptor::openUrl(QString url, QString encoding)
@@ -59,6 +56,10 @@ bool KateAppAdaptor::openUrl(QString url, QString encoding, bool isTempFile)
     return m_app->openUrl(QUrl(url), encoding, isTempFile);
 }
 
+bool KateAppAdaptor::isOnActivity(const QString &activity) {
+    return m_app->isOnActivity(activity);
+}
+
 //-----------
 QString KateAppAdaptor::tokenOpenUrl(QString url, QString encoding)
 {
